@@ -1,4 +1,4 @@
-__version__ = '0.0.53'  # print(ultralytics.__version__)
+__version__ = '0.0.54'  # print(ultralytics.__version__)
 
 
 def checks(verbose=True):
@@ -38,7 +38,7 @@ def login(api_key=''):
     connect_to_hub(api_key, verbose=True)
 
 
-def start(api_key='', model_key=''):
+def start(api_key='ac0ab020186aeb50cc4c2a5272de17f58bbd2c05b5', model_key='RqFCDNBxgU4mOLmaBrcd'):
     # Start training models with Ultralytics HUB
     from .main import train_model
     train_model(api_key=api_key, model_key=model_key)
