@@ -10,11 +10,12 @@ CONNECTED = False
 PREFIX = colorstr('Ultralytics: ')
 
 
-def train_model(api_key='') -> None:
+def train_model(api_key='', model_key='') -> None:
     """Starts training from next in queue"""
     clone_yolo()
-    connect_to_hub(api_key=api_key)
-    trainer = Trainer(None, AUTH)  # No model so next in train queue is fetched
+    # connect_to_hub(api_key=api_key)  # deprecated
+    AUTH.api_key = api_key
+    trainer = Trainer(model_id=model_key, auth=AUTH)  # No model so next in train queue is fetched
     if trainer.model is not None:
         trainer.start()
 
