@@ -3,10 +3,11 @@ import subprocess
 from pathlib import Path
 
 from .config import REPO_URL, REPO_BRANCH, ENVIRONMENT
+from .utils.general import emojis
 
 
 def install_dependencies():
-    print('Installing YOLOv5 🚀 requirements...', end=" ")
+    print(emojis('Installing YOLOv5 🚀 requirements...'), end=" ")
     if ENVIRONMENT == 'development':
         subprocess.call(['pip', 'install', '-r', 'yolov5/requirements.txt'])
     else:
@@ -23,7 +24,7 @@ def clone_yolo():
     if not Path("./yolov5").is_dir():
         from git import Repo
         try:
-            print(f"Cloning YOLOv5 🚀 from {REPO_URL}...", end=" ")
+            print(emojis(f"Cloning YOLOv5 🚀 from {REPO_URL}..."), end=" ")
             Repo.clone_from(REPO_URL, "yolov5", branch=REPO_BRANCH)  # Temp solution while waiting on pull request
             print("Done")
             install_dependencies()
